<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../about.ui" line="48"/>
        <source>Lightweight file manager</source>
        <translation>輕量級檔案管理程式</translation>
    </message>
    <message>
        <location filename="../about.ui" line="122"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</source>
        <translation>程式：
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="25"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM-Qt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM-Qt 檔案管理程式&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="58"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt&quot;&gt;https://github.com/lxqt/pcmanfm-qt&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt&quot;&gt;https://github.com/lxqt/pcmanfm-qt&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="74"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Wiki: &lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt/wiki&quot;&gt;https://github.com/lxqt/pcmanfm-qt/wiki&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Wiki: &lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt/wiki&quot;&gt;https://github.com/lxqt/pcmanfm-qt/wiki&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="113"/>
        <source>Authors</source>
        <translation>作者</translation>
    </message>
    <message>
        <location filename="../about.ui" line="135"/>
        <source>License</source>
        <translation>授權</translation>
    </message>
    <message>
        <location filename="../about.ui" line="144"/>
        <source>PCManFM-Qt File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>PCManFM-Qt 檔案管理程式

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</translation>
    </message>
</context>
<context>
    <name>AutoRunDialog</name>
    <message>
        <location filename="../autorun.ui" line="14"/>
        <source>Removable medium is inserted</source>
        <translation>插入可移除式裝置</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="33"/>
        <source>&lt;b&gt;Removable medium is inserted&lt;/b&gt;</source>
        <translation>&lt;b&gt;插入可移除式裝置&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="40"/>
        <source>Type of medium:</source>
        <translation>媒體種類:</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="47"/>
        <source>Detecting...</source>
        <translation>正在偵測...</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="56"/>
        <source>Please select the action you want to perform:</source>
        <translation>請選擇想要執行的動作:</translation>
    </message>
</context>
<context>
    <name>BulkRenameDialog</name>
    <message>
        <location filename="../bulk-rename.ui" line="6"/>
        <source>Bulk Rename</source>
        <translation>批量重新命名</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="47"/>
        <source># will be replaced by numbers starting with:</source>
        <translation># 將會被開始數量取代：</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="80"/>
        <source>Pad numbers with zero if possible</source>
        <translation>需要時補零</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="87"/>
        <source>Use localized numbers</source>
        <translation>使用在地語系的數字</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="27"/>
        <source>Rename selected files to:</source>
        <translation>重新命名選取的檔案：</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="40"/>
        <source>Name#</source>
        <translation>名稱#</translation>
    </message>
</context>
<context>
    <name>ConnectServerDialog</name>
    <message>
        <location filename="../connect.ui" line="14"/>
        <source>Connect to remote server</source>
        <translation>連線到遠端伺服器</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="80"/>
        <source>Anonymous &amp;login</source>
        <translation>匿名登入 (&amp;L)</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="90"/>
        <source>Login as &amp;user:</source>
        <translation>以使用者名稱登入 (&amp;U):</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="29"/>
        <source>Specify remote folder to connect</source>
        <translation>指定要連線的遠端目錄</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="36"/>
        <source>Type:</source>
        <translation>型態:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="56"/>
        <source>Port:</source>
        <translation>連接埠:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="70"/>
        <source>Path:</source>
        <translation>路徑:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="46"/>
        <source>Host:</source>
        <translation>主機:</translation>
    </message>
</context>
<context>
    <name>DesktopEntryDialog</name>
    <message>
        <location filename="../desktopentrydialog.ui" line="14"/>
        <source>Create Launcher</source>
        <translation>建立啟動器</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="38"/>
        <source>Name:</source>
        <translation>名稱:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="45"/>
        <source>Specific name of this launcher.</source>
        <translation>這個啟動器的名稱。</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="58"/>
        <source>Description:</source>
        <translation>描述:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="65"/>
        <source>A short description or generic name, like &quot;Web Browser&quot; or &quot;Home Directory&quot;.

It can be left empty.</source>
        <translation>簡短的描述，或是像是「網路瀏覽器」及「家目錄」這種一般性的名字。

可以留空。</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="77"/>
        <source>Comment:</source>
        <translation>註解:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="84"/>
        <source>A short comment.

It can be left empty.</source>
        <translation>簡短的註解。

可以留空。</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="117"/>
        <source>Command:</source>
        <translation>指令:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="133"/>
        <location filename="../desktopentrydialog.ui" line="164"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="142"/>
        <source>Icon:</source>
        <translation>圖示:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="151"/>
        <source>Icon to display in file manager, menus, etc.</source>
        <translation>在檔案管理程式、選單等之中顯示的圖示。</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="173"/>
        <location filename="../desktopentrydialog.ui" line="183"/>
        <source>Run in terminal?</source>
        <translation>在終端機裡執行？</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="176"/>
        <source>Terminal:</source>
        <translation>終端機:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="186"/>
        <source>Whether the launched program should run in a terminal window.</source>
        <translation>是否應於終端機中執行這個程式。</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="190"/>
        <source>No</source>
        <translation>否</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="195"/>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="203"/>
        <source>Type:</source>
        <translation>類型:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="210"/>
        <source>Whether this is a link or executes a command.</source>
        <translation>這是連結或是執行指令。</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="214"/>
        <source>Application</source>
        <translation>應用程式</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="219"/>
        <source>Link</source>
        <translation>連結</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="96"/>
        <source>Categories:</source>
        <translation>類別：</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="103"/>
        <source>Semicolon separated categories in which the entry should be shown if it is used by the DE&apos;s main menu (e.g., when put inside ~/.local/share/applications).

It is needed only when you want to use the created file in the main menu. Otherwise, you could leave it empty.

Examples: AudioVideo, Audio, Video, Development, Education, Game, Graphics, Network, Office, Settings, System, Utility, Qt.</source>
        <translation>逗號分隔的分類。當被用於桌面環境的主選單時 (例如放在 ~/.local/share/applications/)，會依據這個這個分類來決定這個啟動器應該放在哪裡。

只有在您是為了主選單建立啟動器時才需要填入這個欄位，否則可留空。

範例: AudioVideo, Audio, Video, Development, Education, Game, Graphics, Network, Office, Settings, System, Utility, Qt.</translation>
    </message>
</context>
<context>
    <name>DesktopFolder</name>
    <message>
        <location filename="../desktop-folder.ui" line="14"/>
        <source>Form</source>
        <translation>表單</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="23"/>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="29"/>
        <source>Desktop folder:</source>
        <translation>桌面資料夾:</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="36"/>
        <source>Image file</source>
        <translation>影像檔案</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="42"/>
        <source>Folder path</source>
        <translation>資料夾路徑</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="49"/>
        <source>&amp;Browse</source>
        <translation>瀏覽(&amp;B)</translation>
    </message>
</context>
<context>
    <name>DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktop-preferences.ui" line="14"/>
        <source>Desktop Preferences</source>
        <translation>桌面偏好設定</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="338"/>
        <location filename="../desktop-preferences.ui" line="344"/>
        <source>Background</source>
        <translation>背景</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="385"/>
        <source>Wallpaper mode:</source>
        <translation>桌布:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="408"/>
        <source>Wallpaper image file:</source>
        <translation>桌布影像檔案:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="350"/>
        <source>Select background color:</source>
        <translation>選擇背景顏色:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="417"/>
        <source>Image file</source>
        <translation>影像檔案</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="423"/>
        <source>Image file path</source>
        <translation>影像檔路徑</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="430"/>
        <source>&amp;Browse</source>
        <translation>瀏覽(&amp;B)</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="30"/>
        <source>Icons</source>
        <translation>圖示</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="36"/>
        <source>Icon size:</source>
        <translation>圖示大小:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="49"/>
        <source>Label Text</source>
        <translation>標籤文字</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="113"/>
        <source>Select shadow color:</source>
        <translation>選擇陰影顏色:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="61"/>
        <source>Select font:</source>
        <translation>選擇字型:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="24"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="87"/>
        <source>Select text color:</source>
        <translation>選擇文字顏色:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="136"/>
        <source>Spacing</source>
        <translation>間距</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="145"/>
        <source>Minimum item margins:</source>
        <translation>項目邊緣留空:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="152"/>
        <source>3 px by default.</source>
        <translation>預設 3 像素。</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="155"/>
        <location filename="../desktop-preferences.ui" line="179"/>
        <location filename="../desktop-preferences.ui" line="237"/>
        <location filename="../desktop-preferences.ui" line="249"/>
        <location filename="../desktop-preferences.ui" line="275"/>
        <location filename="../desktop-preferences.ui" line="287"/>
        <source> px</source>
        <translation> 像素</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="168"/>
        <source>x</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="175"/>
        <source>1 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation>預設 1 像素。
還會額外保留三行文字高度的空間。</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="192"/>
        <source>Lock</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="230"/>
        <source>Margins of work area:</source>
        <translation>工作區各邊界的距離:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="303"/>
        <source>By default, desktop folders will be opened in PCManFM-Qt if they
are left clicked, even when it is not the default file manager.</source>
        <translation>在預設情況下，當點擊桌面上的資料夾時，
即使預設的檔案管理程式不是 PCManFM-Qt，也會以 PCManFM-Qt 開啟。</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="307"/>
        <source>Open desktop folders in default file manager by left clicking</source>
        <translation>以預設的檔案管理程式開啟桌面上的資料夾</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="314"/>
        <source>Make all items stick to their positions</source>
        <translation>使所有桌面圖示不被自動排列</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="373"/>
        <source>Wallpaper</source>
        <translation>桌布</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="439"/>
        <source>Transform image based on EXIF data</source>
        <translation>基於 EXIF 資訊自動調整圖片</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="446"/>
        <source>Individual wallpaper for each monitor</source>
        <translation>各個顯示器獨立設定桌布</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="473"/>
        <source>Slide Show</source>
        <translation>幻燈片播放</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="479"/>
        <source>Enable Slide Show</source>
        <translation>啟用幻燈片播放</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="491"/>
        <source>Wallpaper image folder:</source>
        <translation>桌布圖片資料夾：</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="505"/>
        <source>Browse</source>
        <translation>瀏覽</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="512"/>
        <source> hour(s)</source>
        <translation> 小時</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="522"/>
        <source>and</source>
        <translation>和</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="535"/>
        <source>Intervals less than 5min will be ignored</source>
        <translation>小於5分鐘的區間將被忽略</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="538"/>
        <source>Interval:</source>
        <translation>區間：</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="545"/>
        <source> minute(s)</source>
        <translation> 分鐘</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="498"/>
        <source>Wallpaper folder</source>
        <translation>桌布資料夾</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="587"/>
        <source>Randomize the slide show</source>
        <translation>隨機幻燈片播放</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="620"/>
        <source>Visible Shortcuts</source>
        <translation>可見的快捷方式</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="626"/>
        <source>Home</source>
        <translation>家目錄</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="637"/>
        <source>Trash</source>
        <translation>垃圾桶</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="648"/>
        <source>Computer</source>
        <translation>電腦</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="659"/>
        <source>Network</source>
        <translation>網路</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="614"/>
        <source>Advanced</source>
        <translation>進階</translation>
    </message>
</context>
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>隱藏的快捷鍵</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="21"/>
        <source>Shortcut</source>
        <translation>快捷鍵</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="26"/>
        <source>Action</source>
        <translation>動作</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="31"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Focus view, clear filter bar</source>
        <translation>焦點移到主顯示區，並清除搜尋列</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Ctrl+Esc</source>
        <translation>Ctrl+Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="42"/>
        <source>Focus side-pane</source>
        <translation>移動焦點到側邊欄</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="50"/>
        <location filename="../shortcuts.ui" line="58"/>
        <source>Focus path entry</source>
        <translation>移動焦點到路徑輸入框</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <source>Alt+D</source>
        <translation>Alt+D</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Ctrl+Tab</source>
        <translation>Ctrl+Tab</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="66"/>
        <location filename="../shortcuts.ui" line="82"/>
        <source>Next tab</source>
        <translation>下個分頁</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Ctrl+Shift+Tab</source>
        <translation>Ctrl+Shift+Tab</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="74"/>
        <location filename="../shortcuts.ui" line="90"/>
        <source>Previous tab</source>
        <translation>上個分頁</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <source>Ctrl+PageDown</source>
        <translation>Ctrl+PageDown</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Ctrl+PageUp</source>
        <translation>Ctrl+PageUp</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>Ctrl+Number</source>
        <translation>Ctrl+數字鍵</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="98"/>
        <location filename="../shortcuts.ui" line="106"/>
        <source>Jump to tab</source>
        <translation>跳到分頁</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="103"/>
        <source>Alt+Number</source>
        <translation>Alt+數字鍵</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="111"/>
        <source>Backspace</source>
        <translation>Backspace</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="114"/>
        <source>Go up</source>
        <translation>往上一層</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="119"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="122"/>
        <source>Search dialog</source>
        <translation>搜尋對話框</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="127"/>
        <source>Shift+Insert</source>
        <translation>Shift+Insert</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="130"/>
        <source>Paste into transient filter bar</source>
        <translation>貼到臨時搜尋框</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="135"/>
        <source>Drop+Shift</source>
        <translation>拖曳+Shift</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="143"/>
        <source>Drop+Ctrl</source>
        <translation>拖曳+Ctrl</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="151"/>
        <source>Drop+Shift+Ctrl</source>
        <translation>拖曳+Shift+Ctrl</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="138"/>
        <source>Move file on dropping</source>
        <translation>拖曳放開時移動檔案</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="146"/>
        <source>Copy file on dropping</source>
        <translation>拖曳放開時複製檔案</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="154"/>
        <source>Make a symlink on dropping</source>
        <translation>在拖曳放開時建立符號連結</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main-win.ui" line="14"/>
        <source>File Manager</source>
        <translation>檔案管理程式</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="290"/>
        <source>Go Up</source>
        <translation>往上一層</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="293"/>
        <source>Alt+Up</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="305"/>
        <source>Alt+Home</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="421"/>
        <source>Reload</source>
        <translation>重新讀取</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="317"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="81"/>
        <source>Recent F&amp;iles</source>
        <translation>最近使用的檔案 (&amp;I)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="139"/>
        <source>&amp;Toolbars</source>
        <translation>工具列(&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="146"/>
        <source>Path &amp;Bar</source>
        <translation>路徑工具列 (&amp;B)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="153"/>
        <source>&amp;Filtering</source>
        <translation>篩選(&amp;F)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="228"/>
        <source>&amp;Tools</source>
        <translation>工具 (&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="287"/>
        <source>Go &amp;Up</source>
        <translation>上一層(&amp;U)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="302"/>
        <source>&amp;Home</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="314"/>
        <source>&amp;Reload</source>
        <translation>重新讀取(&amp;R)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="326"/>
        <source>Go</source>
        <translation>前往</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="335"/>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="344"/>
        <source>&amp;About</source>
        <translation>關於(&amp;A)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="353"/>
        <source>&amp;New Window</source>
        <translation>新視窗(&amp;N)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="356"/>
        <source>New Window</source>
        <translation>新視窗</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="359"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="367"/>
        <source>Show &amp;Hidden</source>
        <translation>顯示隱藏檔(&amp;H)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="370"/>
        <source>Ctrl+H</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="379"/>
        <source>&amp;Computer</source>
        <translation>電腦(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="388"/>
        <source>&amp;Trash</source>
        <translation>垃圾桶(&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="393"/>
        <source>&amp;Network</source>
        <translation>網路(&amp;N)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="402"/>
        <source>&amp;Desktop</source>
        <translation>桌面(&amp;D)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="411"/>
        <source>&amp;Add to Bookmarks</source>
        <translation>加入到書籤(&amp;A)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="416"/>
        <source>&amp;Applications</source>
        <translation>應用程式(&amp;A)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="429"/>
        <source>&amp;Icon View</source>
        <translation>圖示檢視(&amp;I)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="437"/>
        <source>&amp;Compact View</source>
        <translation>簡易檢視(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="445"/>
        <source>&amp;Detailed List</source>
        <translation>詳細清單(&amp;D)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="453"/>
        <source>&amp;Thumbnail View</source>
        <translation>縮圖檢視(&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="462"/>
        <source>Cu&amp;t</source>
        <translation>剪下(&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="502"/>
        <source>De&amp;select All</source>
        <translation>取消全部選取 (&amp;S)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="505"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="518"/>
        <source>&amp;Ascending</source>
        <translation>升冪排列(&amp;A)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="526"/>
        <source>&amp;Descending</source>
        <translation>降冪排列(&amp;D)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="534"/>
        <source>&amp;By File Name</source>
        <translation>以檔案名稱( &amp;B)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="542"/>
        <source>By &amp;Modification Time</source>
        <translation>以最後修改時間 (&amp;M)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="550"/>
        <source>By C&amp;reation Time</source>
        <translation>以建立時間 (&amp;R)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="558"/>
        <source>By Deletio&amp;n Time</source>
        <translation>以刪除時間 (&amp;N)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="566"/>
        <source>By File &amp;Type</source>
        <translation>以檔案型態 (&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="574"/>
        <source>By &amp;Owner</source>
        <translation>以擁有者 (&amp;O)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="582"/>
        <source>By &amp;Group</source>
        <translation>依照群組</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="590"/>
        <source>&amp;Folder First</source>
        <translation>資料夾優先 (&amp;F)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="598"/>
        <source>&amp;Hidden Last</source>
        <translation>隱藏檔顯示在最後 (&amp;H)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="879"/>
        <source>Shift+F2</source>
        <translation>Shift+F2</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="963"/>
        <source>Preserve Settings Recursively from &amp;Here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="968"/>
        <source>&amp;Go to Source of Inherited Settings</source>
        <translation>跳到繼承的設定的來源 (&amp;G)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="973"/>
        <source>&amp;Remove Settings of Nonexistent Folders</source>
        <translation>刪除不存在的資料夾的設定 (&amp;R)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="981"/>
        <source>&amp;Clear</source>
        <translation>清除 (&amp;C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="651"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="676"/>
        <source>C&amp;lose Tab</source>
        <translation>關閉(&amp;L)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="684"/>
        <source>File &amp;Properties</source>
        <translation>檔案屬性(&amp;P)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="692"/>
        <source>&amp;Folder Properties</source>
        <translation>資料夾屬性(&amp;F)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="700"/>
        <source>&amp;Case Sensitive</source>
        <translation>區分大小寫 (&amp;C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="708"/>
        <source>By File &amp;Size</source>
        <translation>依照檔案大小 (&amp;S)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="713"/>
        <source>&amp;Close Window</source>
        <translation>關閉視窗 (&amp;C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="716"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="734"/>
        <source>Open Tab in &amp;Root Instance</source>
        <translation type="unfinished">以 root 實例開啟分頁(&amp;R)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="751"/>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="763"/>
        <source>Ctrl+Alt+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="847"/>
        <source>Preserve Settings for &amp;This Folder</source>
        <translation>儲存這個資料夾的設定 (&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="884"/>
        <source>&amp;Show/Focus Filter Bar</source>
        <translation>顯示/聚焦篩選條(&amp;S)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="887"/>
        <source>Show Filter Bar</source>
        <translation>顯示篩選欄</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="890"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="898"/>
        <source>S&amp;plit View</source>
        <translation>分割視圖(&amp;p)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="901"/>
        <source>Split View</source>
        <translation>分割視圖</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="904"/>
        <source>F6</source>
        <translation>F6</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="909"/>
        <source>&amp;Copy Full Path</source>
        <translation>複製完整路徑(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="912"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Shift+C</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="923"/>
        <source>Show Thumb&amp;nails</source>
        <translation>顯示縮圖 (&amp;N)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="926"/>
        <source>Show Thumbnails</source>
        <translation>顯示縮圖</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="934"/>
        <source>S&amp;ide Pane</source>
        <translation>側邊欄 (&amp;I)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="937"/>
        <source>F9</source>
        <translation>F9</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="942"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>隱藏的快捷鍵 (&amp;S)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="947"/>
        <source>Open Tab in &amp;Admin Mode</source>
        <translation>以管理員模式開啟分頁(&amp;A)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="952"/>
        <location filename="../main-win.ui" line="955"/>
        <source>Create Launcher</source>
        <translation>建立啟動器</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="782"/>
        <source>Ctrl+B</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="787"/>
        <source>&amp;Clear All Filters</source>
        <translation>清空全部篩選條件(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="790"/>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="799"/>
        <source>Close &amp;previous tabs</source>
        <translation>關閉前一個分頁 &amp;P)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="808"/>
        <source>Close &amp;next tabs</source>
        <translation>關閉下一個分頁 (&amp;N)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="852"/>
        <source>Connect to &amp;Server</source>
        <translation>連線到伺服器 (&amp;S)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="860"/>
        <source>&amp;Location</source>
        <translation>位置 (&amp;L)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="868"/>
        <source>&amp;Path Buttons</source>
        <translation>路徑按鈕 (&amp;P)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="873"/>
        <source>&amp;Bulk Rename</source>
        <translation>批量重新命名 (&amp;B)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="876"/>
        <source>Bulk Rename</source>
        <translation>批量重新命名</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="813"/>
        <source>Close &amp;other tabs</source>
        <translation>關閉其他分頁 (&amp;O)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="779"/>
        <source>Permanent &amp;filter bar</source>
        <translation>固定篩選欄(&amp;f)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="821"/>
        <source>&amp;Menu bar</source>
        <translation>選單列 (&amp;M)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="824"/>
        <source>Menu bar</source>
        <translation>選單列</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="827"/>
        <source>Ctrl+M</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="836"/>
        <location filename="../main-win.ui" line="839"/>
        <source>Menu</source>
        <translation>選單</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="74"/>
        <source>C&amp;reate New</source>
        <translation>新建 (&amp;R)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="109"/>
        <source>&amp;Sorting</source>
        <translation>排序(&amp;S)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="253"/>
        <source>Main Toolbar</source>
        <translation>主選單列</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="465"/>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="474"/>
        <source>&amp;Copy</source>
        <translation>複製 (&amp;C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="477"/>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="486"/>
        <source>&amp;Paste</source>
        <translation>貼上(&amp;P)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="489"/>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="494"/>
        <source>Select &amp;All</source>
        <translation>全選(&amp;A)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="510"/>
        <source>Pr&amp;eferences</source>
        <translation>偏好設定(&amp;R)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="648"/>
        <source>&amp;Invert Selection</source>
        <translation>反向選取(&amp;I)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="660"/>
        <source>&amp;Delete</source>
        <translation>刪除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="668"/>
        <source>&amp;Rename</source>
        <translation>重新命名(&amp;R)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="497"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="160"/>
        <source>&amp;Customized View Settings</source>
        <translation>自訂顯示設定 (&amp;C)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="607"/>
        <source>New &amp;Tab</source>
        <translation>新分頁(&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="610"/>
        <source>New Tab</source>
        <translation>新分頁</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="613"/>
        <source>Ctrl+T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="622"/>
        <source>Go &amp;Back</source>
        <translation>後退(&amp;B)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="625"/>
        <source>Go Back</source>
        <translation>後退</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="628"/>
        <source>Alt+Left</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="637"/>
        <source>Go &amp;Forward</source>
        <translation>前進(&amp;F)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="640"/>
        <source>Go Forward</source>
        <translation>前進</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="643"/>
        <source>Alt+Right</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="663"/>
        <source>Del</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="671"/>
        <source>F2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="679"/>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="687"/>
        <source>Alt+Return</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="721"/>
        <source>Edit Bookmarks</source>
        <translation>編輯書籤</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="726"/>
        <source>Open &amp;Terminal</source>
        <translation>開啟終端機(&amp;T)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="729"/>
        <source>F4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="739"/>
        <source>&amp;Edit Bookmarks</source>
        <translation>編輯書籤(&amp;E)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="748"/>
        <source>&amp;Folder</source>
        <translation>資料夾 (&amp;F)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="760"/>
        <source>&amp;Blank File</source>
        <translation>空白檔案 (&amp;B)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="768"/>
        <source>&amp;Find Files</source>
        <translation>尋找檔案 (&amp;F)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="771"/>
        <source>F3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="70"/>
        <source>&amp;File</source>
        <translation>檔案(&amp;F)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="98"/>
        <source>&amp;Help</source>
        <translation>說明(&amp;H)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="105"/>
        <location filename="../main-win.ui" line="129"/>
        <source>&amp;View</source>
        <translation>檢視(&amp;V)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="185"/>
        <source>&amp;Edit</source>
        <translation>編輯(&amp;E)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="204"/>
        <source>&amp;Bookmarks</source>
        <translation>書籤(&amp;B)</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="211"/>
        <source>&amp;Go</source>
        <translation>前往(&amp;G)</translation>
    </message>
</context>
<context>
    <name>PCManFM::Application</name>
    <message>
        <location filename="../application.cpp" line="187"/>
        <source>Name of configuration profile</source>
        <translation>配置文件名稱</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="187"/>
        <source>PROFILE</source>
        <translation>設定檔</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="190"/>
        <source>Run PCManFM-Qt as a daemon</source>
        <translation>執行 PCManFM 常駐程式</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="193"/>
        <source>Quit PCManFM-Qt</source>
        <translation>離開 PCManFM</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="196"/>
        <source>Launch desktop manager</source>
        <translation>啟動桌面管理器</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="199"/>
        <source>Turn off desktop manager if it&apos;s running</source>
        <translation>關閉執行中的桌面管理器</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="202"/>
        <source>Open desktop preference dialog on the page with the specified name</source>
        <translation>在指定名稱的頁面上開啟桌面偏好設定對話框</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="202"/>
        <location filename="../application.cpp" line="217"/>
        <source>NAME</source>
        <translation>名稱</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="205"/>
        <source>Open new window</source>
        <translation>開啟新視窗</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="208"/>
        <source>Open Find Files utility</source>
        <translation>打開「尋找檔案」工具</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="211"/>
        <source>Set desktop wallpaper from image FILE</source>
        <translation>從圖檔設定桌布</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="211"/>
        <source>FILE</source>
        <translation>檔案</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="214"/>
        <source>MODE</source>
        <translation>模式</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="214"/>
        <source>Set mode of desktop wallpaper. MODE=(%1)</source>
        <translation>設定桌布模式。模式=(%1)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="217"/>
        <source>Open Preferences dialog on the page with the specified name</source>
        <translation>在指定名稱的頁面打開偏好設定對話框</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="220"/>
        <source>Files or directories to open</source>
        <translation>開啟檔案或目錄</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="220"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[檔案1, 檔案2,...]</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="655"/>
        <location filename="../application.cpp" line="660"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="660"/>
        <source>Terminal emulator is not set.</source>
        <translation>終端機模擬器尚未設定。</translation>
    </message>
</context>
<context>
    <name>PCManFM::AutoRunDialog</name>
    <message>
        <location filename="../autorundialog.cpp" line="44"/>
        <source>Open in file manager</source>
        <translation>在檔案管理程式內開啟</translation>
    </message>
    <message>
        <location filename="../autorundialog.cpp" line="138"/>
        <source>Removable Disk</source>
        <translation>可移除式磁碟</translation>
    </message>
</context>
<context>
    <name>PCManFM::ConnectServerDialog</name>
    <message>
        <location filename="../connectserverdialog.cpp" line="9"/>
        <source>SSH</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="10"/>
        <source>FTP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="11"/>
        <source>WebDav</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="12"/>
        <source>Secure WebDav</source>
        <translation>安全 WebDav</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="13"/>
        <source>HTTP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="14"/>
        <source>HTTPS</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopEntryDialog</name>
    <message>
        <location filename="../desktopentrydialog.cpp" line="35"/>
        <source>Command:</source>
        <translation>指令:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="36"/>
        <source>The command to execute.</source>
        <translation>要執行的指令。</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="39"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="40"/>
        <source>The URL to access.</source>
        <translation>要存取的 URL。</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="67"/>
        <source>Select an icon</source>
        <translation>選擇一個圖示</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="69"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>圖片 (*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="91"/>
        <source>Select an executable file</source>
        <translation>選擇一個可執行檔</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="99"/>
        <source>Select a file</source>
        <translation>選擇一個檔案</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="52"/>
        <source>Fill with background color only</source>
        <translation>只以背景色填滿</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="53"/>
        <source>Stretch to fill the entire screen</source>
        <translation>延展以填滿整個螢幕</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="54"/>
        <source>Stretch to fit the screen</source>
        <translation>延展到最適合螢幕大小</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="55"/>
        <source>Center on the screen</source>
        <translation>置於螢幕中央</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="56"/>
        <source>Tile the image to fill the entire screen</source>
        <translation>連續拼貼鋪滿整個螢幕</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="57"/>
        <source>Zoom the image to fill the entire screen</source>
        <translation>縮放影像填滿整個螢幕</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="264"/>
        <source>Select Wallpaper</source>
        <translation>選擇桌布</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="268"/>
        <source>Image Files</source>
        <translation>影像檔案</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="310"/>
        <source>Select Wallpaper Folder</source>
        <translation>選擇桌布資料夾</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopWindow</name>
    <message>
        <location filename="../desktopwindow.cpp" line="303"/>
        <source>Trash (One item)</source>
        <translation>垃圾桶(1個項目)</translation>
    </message>
    <message numerus="yes">
        <location filename="../desktopwindow.cpp" line="306"/>
        <source>Trash (%Ln items)</source>
        <translation>
            <numerusform>垃圾桶(%Ln個項目)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="310"/>
        <source>Trash (Empty)</source>
        <translation>垃圾桶(空)</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="345"/>
        <source>Computer</source>
        <translation>電腦</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="359"/>
        <source>Network</source>
        <translation>網路</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1011"/>
        <source>Open</source>
        <translation>開啟</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1017"/>
        <location filename="../desktopwindow.cpp" line="1057"/>
        <source>Stic&amp;k to Current Position</source>
        <translation>保持在目前位置(&amp;K)</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1025"/>
        <source>Empty Trash</source>
        <translation>清空垃圾箱</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1084"/>
        <source>Hide Desktop Items</source>
        <translation>隱藏桌面項目</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1090"/>
        <source>Create Launcher</source>
        <translation>建立啟動器</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1093"/>
        <source>Desktop Preferences</source>
        <translation>桌面偏好設定</translation>
    </message>
</context>
<context>
    <name>PCManFM::FilterBar</name>
    <message>
        <location filename="../tabpage.cpp" line="95"/>
        <source>Filter:</source>
        <translation>篩選:</translation>
    </message>
</context>
<context>
    <name>PCManFM::FilterEdit</name>
    <message>
        <location filename="../tabpage.cpp" line="65"/>
        <source>Clear text (Ctrl+K or Esc)</source>
        <translation>清除文字 (Ctrl+K 或 Esc)</translation>
    </message>
</context>
<context>
    <name>PCManFM::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>Root Instance</source>
        <translation>Root 模式</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="780"/>
        <source>Hide menu bar</source>
        <translation>隱藏選單列</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="781"/>
        <source>This will hide the menu bar completely, use Ctrl+M to show it again.</source>
        <translation>選單列將完全被隱藏，使用 Ctrl+M 可再次顯示。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1228"/>
        <source>Version: %1</source>
        <translation>版本: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <location filename="../mainwindow.cpp" line="2203"/>
        <source>&amp;Move to Trash</source>
        <translation>移動到垃圾桶(&amp;M)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <location filename="../mainwindow.cpp" line="2203"/>
        <source>&amp;Delete</source>
        <translation>刪除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2039"/>
        <source>Customized View Settings</source>
        <translation>自訂顯示設定</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2310"/>
        <location filename="../mainwindow.cpp" line="2318"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2318"/>
        <source>Switch user command is not set.</source>
        <translation>切換使用者指令尚未設定。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2420"/>
        <source>Cleaning Folder Settings</source>
        <translation>清除資料夾設定</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2421"/>
        <source>Do you want to remove settings of nonexistent folders?
They might be useful if those folders are created again.</source>
        <translation>請問您要刪除資料夾不存在的設定嗎？
如果又重新建立資料夾時可能會有用。</translation>
    </message>
</context>
<context>
    <name>PCManFM::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="206"/>
        <source>Icon View</source>
        <translation>圖示檢視</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="207"/>
        <source>Compact View</source>
        <translation>簡易檢視</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="208"/>
        <source>Thumbnail View</source>
        <translation>縮圖檢視</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="209"/>
        <source>Detailed List View</source>
        <translation>詳細清單檢視</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="279"/>
        <source>Remove if added by user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="303"/>
        <source>Open user-defined list</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::TabPage</name>
    <message>
        <location filename="../tabpage.cpp" line="443"/>
        <source>Search Results</source>
        <translation>搜尋結果</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="446"/>
        <source>Applications</source>
        <translation>應用程式</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="450"/>
        <source>Computer</source>
        <translation>電腦</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="453"/>
        <source>Network</source>
        <translation>網路</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="456"/>
        <source>Trash</source>
        <translation>垃圾桶</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="462"/>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="553"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="562"/>
        <source>Free space: %1 (Total: %2)</source>
        <translation>可用空間 %1 (全部: %2)</translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="579"/>
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n 個項目</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="581"/>
        <source> (%n hidden)</source>
        <translation>
            <numerusform> (%n 個隱藏)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="586"/>
        <location filename="../tabpage.cpp" line="789"/>
        <location filename="../tabpage.cpp" line="803"/>
        <source>Link to</source>
        <translation>連結到</translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="815"/>
        <source>%n item(s) selected</source>
        <translation>
            <numerusform>選取 %n 個項目</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PCManFM::View</name>
    <message>
        <location filename="../view.cpp" line="59"/>
        <source>Many files</source>
        <translation>許多檔案</translation>
    </message>
    <message numerus="yes">
        <location filename="../view.cpp" line="60"/>
        <source>Do you want to open these %1 files?</source>
        <translation>
            <numerusform>請問您要開啟這 %1 個檔案嗎？</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../view.cpp" line="122"/>
        <source>Open in New T&amp;ab</source>
        <translation>在新分頁開啟 (&amp;A)</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="126"/>
        <source>Open in New Win&amp;dow</source>
        <translation>在新視窗開啟 (&amp;D)</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="134"/>
        <location filename="../view.cpp" line="152"/>
        <source>Open in Termina&amp;l</source>
        <translation>在終端機內開啟 (&amp;L)</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferences.ui" line="14"/>
        <source>Preferences</source>
        <translation>偏好設定</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="45"/>
        <source>User Interface</source>
        <translation>使用者界面</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="35"/>
        <source>Behavior</source>
        <translation>行為</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="40"/>
        <source>Display</source>
        <translation>顯示</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="50"/>
        <location filename="../preferences.ui" line="642"/>
        <source>Thumbnail</source>
        <translation>縮圖</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="55"/>
        <source>Volume</source>
        <translation>磁碟</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="60"/>
        <source>Advanced</source>
        <translation>進階</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="103"/>
        <location filename="../preferences.ui" line="116"/>
        <source>Set to zero to disable auto-selection.</source>
        <translation>設為 0 以停用自動選取。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="106"/>
        <source>Delay of auto-selection in single click mode:</source>
        <translation>在單點模式下的自動選取延遲:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="144"/>
        <source>Open in current tab</source>
        <translation>在目前分頁開啟</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="149"/>
        <source>Open in new tab</source>
        <translation>在新分頁開啟</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="154"/>
        <source>Open in new window</source>
        <translation>在新視窗開啟</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="129"/>
        <source>Show folder context menu with Ctrl + right click</source>
        <translation>Ctrl+右鍵以顯示資料夾的右鍵選單</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="195"/>
        <source>Erase files on removable media instead of &quot;trash can&quot; creation</source>
        <translation>在可移除裝置上直接刪除檔案，而不移到垃圾桶</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="202"/>
        <source>Confirm before moving files into &quot;trash can&quot;</source>
        <translation>將檔案移到垃圾桶前先確認</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="209"/>
        <location filename="../preferences.ui" line="409"/>
        <location filename="../preferences.ui" line="419"/>
        <source>Requires application restart to take effect completely</source>
        <translation>需要重新啟動應用程式才能完全生效</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="212"/>
        <source>Launch executable files without prompt</source>
        <translation>啟動可執行檔時不提示</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="229"/>
        <source>Open folders in new tabs as far as possible</source>
        <translation>盡可能在新分頁開啟資料夾</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="232"/>
        <source>Single window mode</source>
        <translation>單視窗模式</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="296"/>
        <source>Icons</source>
        <translation>圖示</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="328"/>
        <source>Size of big icons:</source>
        <translation>大圖示尺寸:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="345"/>
        <source>Size of small icons:</source>
        <translation>小圖示尺寸:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="362"/>
        <source>Size of thumbnails:</source>
        <translation>縮圖尺寸:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="376"/>
        <source>Size of side pane icons:</source>
        <translation>側邊欄圖示尺寸:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="412"/>
        <source>Always show real file names</source>
        <translation>永遠顯示真實的檔案名稱</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="429"/>
        <source>Do not show file tooltips</source>
        <translation>不要顯示檔案的提示</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="436"/>
        <source>Disable smooth scrolling</source>
        <translation>停用平滑捲動</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="919"/>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="934"/>
        <source>Maximum search history:</source>
        <translation>搜尋紀錄上限:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="948"/>
        <source>Clear search history</source>
        <translation>清除搜尋紀錄</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="983"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>程式需要重新啓動以使變更生效。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="308"/>
        <source>Icon theme:</source>
        <translation>Icon 主題：</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="546"/>
        <source>Window</source>
        <translation>視窗</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="587"/>
        <source>Default width of new windows:</source>
        <translation>新視窗的預設寬度：</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="601"/>
        <source>Default height of new windows:</source>
        <translation>新視窗的預設高度：</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="559"/>
        <source>Always show the tab bar</source>
        <translation>總是顯示標籤列</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="566"/>
        <source>Show &apos;Close&apos; buttons on tabs	</source>
        <translation>在分頁標籤上顯示「關閉」按鈕	</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="580"/>
        <source>Remember the size of the last closed window</source>
        <translation>記住最後關閉視窗的大小</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="81"/>
        <source>Browsing</source>
        <translation>瀏覽</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="90"/>
        <source>If this is unchecked, the DE setting will be used.</source>
        <translation>如果取消選取，則會使用桌面環境的設定值。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="93"/>
        <source>Open files with single click</source>
        <translation>單擊開啟檔案</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="162"/>
        <source>Default view mode:</source>
        <translation>預設檢視模式:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="119"/>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="136"/>
        <source>Bookmarks menu:</source>
        <translation>書籤選單:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="175"/>
        <source>File Operations</source>
        <translation>檔案操作</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="181"/>
        <source>Confirm before deleting files</source>
        <translation>刪除檔案前確認</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="188"/>
        <source>Move deleted files to &quot;trash bin&quot; instead of erasing from disk.</source>
        <translation>將檔案移動到垃圾桶，而不直接刪除。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="219"/>
        <source>Renamed files will also be selected</source>
        <translation>也會選取更名過的檔案</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="222"/>
        <source>Select newly created files</source>
        <translation>選擇新建立的檔案</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="244"/>
        <source>Number of recent files:</source>
        <translation>最近檔案的數量：</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="325"/>
        <location filename="../preferences.ui" line="335"/>
        <source>Used by Icon View</source>
        <translation>由圖示檢視使用</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="342"/>
        <location filename="../preferences.ui" line="352"/>
        <source>Used by Compact View and Detailed List View</source>
        <translation>由簡易檢視和詳細清單列表使用</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="359"/>
        <location filename="../preferences.ui" line="369"/>
        <source>Used by Thumbnail View</source>
        <translation>縮圖檢視使用</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="389"/>
        <source>User interface</source>
        <translation>使用者界面</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="402"/>
        <source>Treat backup files as hidden</source>
        <translation>將備份檔案視為隱藏檔</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="422"/>
        <source>Show icons of hidden files shadowed</source>
        <translation>陰影化顯示隱藏檔案的圖示</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="459"/>
        <source>Minimum item margins in icon view:</source>
        <translation>圖示檢視項目邊緣留空：</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="466"/>
        <source>3 px by default.</source>
        <translation>預設 3 像素。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="469"/>
        <location filename="../preferences.ui" line="493"/>
        <source> px</source>
        <translation> 像素</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="482"/>
        <source>x</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="489"/>
        <source>3 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation>預設 3 像素。
還會額外保留三行文字高度的空間。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="506"/>
        <source>Lock</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="555"/>
        <source>When unchecked, the tab bar will be shown
only if there are more than one tab.</source>
        <translation>若取消，分頁工具列只會在有多於一個分頁的時候顯示。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="573"/>
        <source>Switch to newly opened tab</source>
        <translation>切換到新分頁</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="615"/>
        <source>Reopen last window tabs in a new window</source>
        <translation>在新視窗開啟上次的分頁</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="648"/>
        <source>Needs ffmpegthumbnailer</source>
        <translation>需要 ffmpegthumbnailer</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="651"/>
        <source>Show thumbnails of files</source>
        <translation>顯示檔案縮圖</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="665"/>
        <location filename="../preferences.ui" line="677"/>
        <source>The built-in thumbnailer makes thumbnails of images that are supported by Qt.

Usually, most image types are supported. The default size limit is 4 MiB.</source>
        <translation>內建的縮圖產生器會為 Qt 支援的圖片格式產生縮圖。

通常大多數的圖片都有支援。預設檔案大小限制是 4 MiB。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="670"/>
        <source>Image size limit for built-in thumbnailer:</source>
        <translation>內建縮圖產生器的圖片檔案大小限制:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="682"/>
        <location filename="../preferences.ui" line="718"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="698"/>
        <location filename="../preferences.ui" line="710"/>
        <source>If existing, external thumbnailers are used for videos, PDF documents, etc.

A value of -1 means that there is no limit for the file size (the default).</source>
        <translation>如果存在外部縮圖產生器，則會用於影片或是 PDF 文件等的縮圖產生。

-1 代表不限制大小。(預設值)</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="703"/>
        <source>File size limit for external thumbnailers:</source>
        <translation>外部縮圖產生器的檔案大小限制:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="715"/>
        <source>No limit</source>
        <translation>無限制</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="860"/>
        <source>Examples:&lt;br&gt;For terminal: &lt;i&gt;xterm -e %s&lt;/i&gt;&lt;br&gt;For switching user: &lt;i&gt;lxsudo %s&lt;/i&gt; or &lt;i&gt;lxsudo dbus-run-session -- %s&lt;/i&gt;&lt;br&gt;&lt;i&gt;%s&lt;/i&gt; is the command line you want to execute with terminal or su.&lt;br&gt; Important: Please use lxsudo, sudo alone will wreck permissions of the settings file.</source>
        <translation>範例：&lt;br&gt;使用終端機執行：&lt;i&gt;xterm -e %s&lt;/i&gt;&lt;br&gt;切換使用者執行：&lt;i&gt;lxsudo %s&lt;/i&gt; or &lt;i&gt;lxsudo dbus-run-session -- %s&lt;/i&gt;&lt;br&gt;&lt;i&gt;%s&lt;/i&gt;是您想要使用終端機或 su 執行的指令。&lt;br&gt;重要：請使用 lxsudo，僅使用 sudo 會破壞設定檔的權限。</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="889"/>
        <source>Templates</source>
        <translation>模板</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="895"/>
        <source>Show only user defined templates in menu</source>
        <translation>選單中只顯示使用者定義的範本</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="902"/>
        <source>Show only one template for each MIME type</source>
        <translation>每個 MIME 型態只顯示一個範本</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="909"/>
        <source>Run default application after creation from template</source>
        <translation>建立檔案範本之後執行預設程式開啟</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="658"/>
        <source>Only show thumbnails for local files</source>
        <translation>只顯示本地檔案的縮圖</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="784"/>
        <source>When removable medium unmounted:</source>
        <translation>當卸載可移除裝置時：</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="847"/>
        <source>Switch &amp;user command:</source>
        <translation>切換使用者的指令:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="873"/>
        <source>Archiver in&amp;tegration:</source>
        <translation>壓縮程式整合:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="833"/>
        <source>Terminal emulator:</source>
        <translation>終端機模擬器:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="754"/>
        <source>Auto Mount</source>
        <translation>自動掛載</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="760"/>
        <source>Mount mountable volumes automatically on program startup</source>
        <translation>掛載可掛載的磁碟</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="767"/>
        <source>Mount removable media automatically when they are inserted</source>
        <translation>可移除式媒體插入時自動掛載</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="774"/>
        <source>Show available options for removable media when they are inserted</source>
        <translation>可移除式媒體插入時顯示可用的選項</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="790"/>
        <source>Close &amp;tab containing removable medium</source>
        <translation>關閉顯示可移除裝置的分頁</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="797"/>
        <source>Chan&amp;ge folder in the tab to home folder</source>
        <translation>將分頁內容改為家目錄</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="824"/>
        <source>Programs</source>
        <translation>程式</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="395"/>
        <source>Use SI decimal prefixes instead of IEC binary prefixes</source>
        <translation>使用SI小數前綴代替IEC二進制前綴</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bulkrename.cpp" line="86"/>
        <source>Renaming files...</source>
        <translation>重新命名檔案...</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="86"/>
        <source>Abort</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="95"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="95"/>
        <source>Renaming is aborted.</source>
        <translation>重新命名被中止。</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="121"/>
        <location filename="../bulkrename.cpp" line="124"/>
        <location filename="../tabpage.cpp" line="1142"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="121"/>
        <source>No file could be renamed.</source>
        <translation>沒有檔案可被重新命名。</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="124"/>
        <source>Some files could not be renamed.</source>
        <translation>某些檔案無法被重新命名。</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="1142"/>
        <source>Cannot open as Admin.</source>
        <translation>無法以管理員身份開啟。</translation>
    </message>
</context>
</TS>
